from .base_model import *


class HltDoctorVisitTable(BaseModel):
    id = models.AutoField(db_column='DoctorVisitTableID', primary_key=True)
    doctor_time_table = models.ForeignKey('HltDoctorTimeTable', db_column='rf_DoctorTimeTableID', **FK_DEFAULT)
    tap = models.ForeignKey('HltTap', db_column='rf_TAPID', **FK_DEFAULT)
    comment = models.CharField(db_column='Comment', max_length=200)
    mkab = models.ForeignKey('HltMkab', db_column='rf_MKABID', **FK_DEFAULT)
    stub_print_counter = models.IntegerField(db_column='StubPrintCounter')
    visit_status = models.IntegerField(db_column='VisitStatus')
    flags = models.IntegerField(db_column='Flags')
    uguid = models.CharField(db_column='UGUID', max_length=36)
    user = models.ForeignKey('XUser', db_column='rf_UserID', **FK_DEFAULT)
    doc_prvd = models.ForeignKey('HltDocPrvd', db_column='rf_DocPRVDID', **FK_DEFAULT)
    from_reg = models.BooleanField(db_column='fromReg')
    from_doc = models.BooleanField(db_column='fromDoc')
    from_infomat = models.BooleanField(db_column='fromInfomat')
    from_internet = models.BooleanField(db_column='fromInternet')
    from_tel = models.BooleanField(db_column='fromTel')
    norma_ue = models.IntegerField(db_column='NormaUE')
    stubn_um = models.CharField(db_column='StubNum', max_length=200)
    confirm_required = models.BooleanField(db_column='confirmRequired')
    edit_history = models.TextField(db_column='editHistory')
    er_id = models.CharField(db_column='ERID', max_length=8000)
    from_other_lpu = models.BooleanField(db_column='fromOtherLPU')
    reserved_to = models.DateTimeField(db_column='ReservedTo')
    direction_id = models.IntegerField(db_column='rf_DirectionID')
    fact_begin_time = models.DateTimeField(db_column='FactBeginTime')
    fact_end_time = models.DateTimeField(db_column='FactEndTime')
    date_time_call = models.DateTimeField(db_column='DateTimeCall')
    date_time_create = models.DateTimeField(db_column='DateTimeCreate')
    date_time_into_lpu = models.DateTimeField(db_column='DateTimeIntoLPU')
    num_ticket_queue = models.CharField(db_column='NumTicketQueue', max_length=200)
    date_visit_first_free = models.DateTimeField(db_column='DateVisitFirstFree')
    is_katl_visit = models.BooleanField(db_column='IsKatlVisit')
    is_confirmed = models.BooleanField(db_column='isConfirmed')
    doctor_visit_status_id = models.IntegerField(db_column='rf_DoctorVisitStatusID')
    prev_dvt_id = models.IntegerField(db_column='rf_PrevDvtID')
    confirmed_fio = models.CharField(db_column='ConfirmedFio', max_length=100)
    confirmed_date = models.DateTimeField(db_column='ConfirmedDate')

    class Meta:
        managed = False
        db_table = 'hlt_DoctorVisitTable'



from .base_model import *


class AtfFileType(BaseModel):
    """
    Тип прикрепленного документа
    """
    id = models.AutoField(db_column='FileTypeID', primary_key=True)
    uuid = models.CharField(db_column='Guid', max_length=36, unique=True, default=uuid.uuid4)

    code = models.CharField(db_column='Code', max_length=100, default='')
    name = models.TextField(db_column='Name')
    description = models.TextField(db_column='Description', default='')
    date_begin = models.DateTimeField(db_column='DateBegin', default=timezone.now)
    date_end = models.DateTimeField(db_column='DateEnd', default=timezone.datetime(2222, 1, 1))

    flags = models.IntegerField(db_column='Flags', default=0)

    class Meta:
        managed = False
        db_table = 'atf_FileType'



from .base_model import *


class KlaHouse(BaseModel):
    id = models.AutoField(db_column='HouseID', primary_key=True)  
    code = models.CharField(db_column='CODE', max_length=17)  
    number = models.CharField(db_column='Number', max_length=10)  
    building = models.CharField(db_column='Building', max_length=10)  
    construction = models.CharField(db_column='Construction', max_length=10)  
    post_index = models.CharField(db_column='PostIndex', max_length=6)  
    street = models.ForeignKey('KlaStreet', models.DO_NOTHING, db_column='rf_StreetID')

    flags = models.IntegerField(db_column='Flags')  

    class Meta:
        managed = False
        db_table = 'kla_House'



from .base_model import *


class HltVisitHistory(BaseModel):
    """
    Обращение
    """
    id = models.AutoField(db_column='VisitHistoryID', primary_key=True)
    uuid = models.CharField(db_column='GUID', max_length=36, unique=True, default=uuid.uuid4)
    date = models.DateTimeField(db_column='Date')
    is_complete = models.BooleanField(db_column='IsComplete')
    doctor_visit_table = models.ForeignKey('HltDoctorVisitTable', db_column='rf_DoctorVisitTableID', **FK_DEFAULT)
    lpu_doctor = models.IntegerField(db_column='rf_LPUDoctorID')
    mkab = models.ForeignKey('HltMkab', models.DO_NOTHING, db_column='rf_MKABID', related_name='visits')
    tap = models.ForeignKey('HltTap', models.DO_NOTHING, db_column='rf_TAPID', related_name='visits')
    begin_time = models.DateTimeField(db_column='BeginTime')
    fact_begin_time = models.DateTimeField(db_column='FactBeginTime')
    fact_end_time = models.DateTimeField(db_column='FactEndTime')
    doc_prvd = models.ForeignKey('HltDocPrvd', db_column='rf_DocPRVDID', **FK_DEFAULT)
    conclusion = models.TextField(db_column='Conclusion')
    date_conclusion = models.DateTimeField(db_column='DateConclusion')

    flags = models.IntegerField(db_column='Flags')

    class Meta:
        managed = False
        db_table = 'hlt_VisitHistory'



from .base_model import *


class HltRepresentativeMkab(BaseModel):
    """
    Представители пациента
    """
    id = models.AutoField(db_column='RepresentativeMKABID', primary_key=True)
    guid = models.CharField(db_column='GUID', max_length=36)
    address_live_str = models.CharField(db_column='AddressLive', max_length=200)
    address_reg_str = models.CharField(db_column='AddressReg', max_length=200)
    bd = models.DateTimeField(db_column='BD')
    birth_place = models.CharField(db_column='Birthplace', max_length=200)
    family = models.CharField(db_column='FAMILY', max_length=40)
    flags = models.IntegerField(db_column='Flags')
    is_main = models.BooleanField(db_column='isMain')
    is_no_ot = models.BooleanField(db_column='isNoOT')
    n_pol = models.CharField(db_column='N_POL', max_length=50)
    name = models.CharField(db_column='NAME', max_length=40)
    ot = models.CharField(db_column='OT', max_length=40)
    other_contact_inf = models.CharField(db_column='OtherContactInf', max_length=255)
    phone = models.CharField(db_column='Phone', max_length=25)
    post = models.CharField(db_column='Post', max_length=255)
    address_live = models.ForeignKey('KlaAddress', **FK_DEFAULT, db_column='rf_AddressLiveID')
    address_reg = models.ForeignKey('KlaAddress', **FK_DEFAULT, db_column='rf_AddressRegID')
    sex_id = models.IntegerField(db_column='rf_kl_SexID')
    tip_oms = models.ForeignKey('OmsKlTipOms', **FK_DEFAULT, db_column='rf_kl_TipOMSID')
    mkab = models.ForeignKey('HltMkab', **FK_DEFAULT, db_column='rf_MKABID')
    not_work_doc_care_id = models.IntegerField(db_column='rf_NotWorkDocCareID')
    patient_mkab = models.ForeignKey('HltMkab', **FK_DEFAULT, db_column='rf_PatientMKABID')
    smo = models.ForeignKey('OmsSmo', **FK_DEFAULT, db_column='rf_SMOID')
    s_pol = models.CharField(db_column='S_POL', max_length=50)
    work = models.CharField(db_column='Work', max_length=200)
    ss = models.CharField(db_column='SS', max_length=14)
    date_doc = models.DateTimeField(db_column='DateDoc')
    doc_issued_by = models.CharField(db_column='DocIssuedBy', max_length=255)
    n_doc = models.CharField(db_column='N_Doc', max_length=15)
    type_doc = models.IntegerField(db_column='rf_TypeDocID')
    s_doc = models.CharField(db_column='S_Doc', max_length=10)
    is_legal_org = models.BooleanField(db_column='isLegalOrg')
    address_org = models.ForeignKey('KlaAddress', **FK_DEFAULT, db_column='rf_AddressOrgID')
    name_org = models.CharField(db_column='NameOrg', max_length=255)
    ogrn_org = models.CharField(db_column='OgrnOrg', max_length=15)
    s_doc_representative = models.CharField(db_column='S_DocRepresentative', max_length=50)
    n_doc_representative = models.CharField(db_column='N_DocRepresentative', max_length=50)
    type_doc_representative_id = models.IntegerField(db_column='rf_TypeDocRepresentativeID')
    date_doc_representative = models.DateTimeField(db_column='DateDocRepresentative')
    doc_representative_by = models.CharField(db_column='DocRepresentativeBy', max_length=255)
    inn = models.CharField(db_column='INN', max_length=12)
    spec_event_cert = models.IntegerField(db_column='rf_SpecEventCertID')
    patient = models.IntegerField(db_column='rf_PatientID')
    oksm = models.IntegerField(db_column='rf_OKSMID')
    vedom = models.IntegerField(db_column='rf_kl_VedomID')

    class Meta:
        managed = False
        db_table = 'hlt_RepresentativeMKAB'



from .base_model import *


class KlaAddress(BaseModel):
    id = models.AutoField(db_column='AddressID', primary_key=True)  
    code = models.CharField(db_column='CODE', max_length=17)  
    address_string = models.CharField(db_column='AddressString', max_length=500)  
    appartment = models.CharField(db_column='Appartment', max_length=50)  
    house = models.ForeignKey('KlaHouse', models.DO_NOTHING, db_column='rf_HouseID')  
    area = models.CharField(db_column='Area', max_length=100)  
    city = models.CharField(db_column='City', max_length=100)  
    dop_data = models.CharField(db_column='DopData', max_length=500)  
    region = models.CharField(db_column='Region', max_length=100)
    country = models.IntegerField(db_column='rf_CountryID')
    street = models.CharField(db_column='Street', max_length=100)
    locality = models.CharField(db_column='Locality', max_length=100)
    post_index = models.CharField(db_column='PostIndex', max_length=6)

    flags = models.IntegerField(db_column='Flags')

    class Meta:
        managed = False
        db_table = 'kla_Address'



class Router:
    def db_for_read(self, model, **hints):
        if model._meta.app_label == 'tmmis':
            return 'tmmis'
        return None

    def db_for_write(self, model, **hints):
        if model._meta.app_label == 'tmmis':
            return 'tmmis'
        return None



from .base_model import *


class OmsTypedoc(BaseModel):
    """
    П: Типы документов, удостоверяющих личность
    """
    id = models.AutoField(db_column='TYPEDOCID', primary_key=True)  
    c_doc = models.BigIntegerField(db_column='C_DOC')  
    name_pfr = models.CharField(db_column='NAME_PFR', max_length=20)  
    name = models.CharField(db_column='NAME', max_length=100)  
    date_b = models.DateTimeField(db_column='Date_B')  
    date_e = models.DateTimeField(db_column='Date_E')  
    doc_num = models.CharField(db_column='DocNum', max_length=20)  
    doc_ser = models.CharField(db_column='DocSer', max_length=10)  
    code_egisz = models.CharField(db_column='CodeEgisz', max_length=150)  

    class Meta:
        managed = False
        db_table = 'oms_TYPEDOC'



from .base_model import *


class HltLpuDoctor(BaseModel):
    """
    Медицинский персонал
    """
    id = models.AutoField(db_column='LPUDoctorID', primary_key=True)
    uuid = models.CharField(db_column='UGUID', max_length=36, unique=True, default=uuid.uuid4)
    pcod = models.CharField(db_column='PCOD', max_length=20)
    ot_v = models.CharField(db_column='OT_V', max_length=20)
    im_v = models.CharField(db_column='IM_V', max_length=20)
    d_ser = models.DateTimeField(db_column='D_SER')
    prvs = models.ForeignKey('OmsPrvs', db_column='rf_PRVSID', **FK_DEFAULT)
    fam_v = models.CharField(db_column='FAM_V', max_length=30)
    kv_kat = models.IntegerField(db_column='rf_KV_KATID')
    msg_text = models.CharField(db_column='MSG_Text', max_length=100)
    lpu = models.IntegerField(db_column='rf_LPUID')
    is_doctor = models.BooleanField(db_column='isDoctor')
    healing_room = models.IntegerField(db_column='rf_HealingRoomID')
    in_time = models.SmallIntegerField(db_column='inTime')
    dr = models.DateTimeField(db_column='DR')
    is_special = models.BooleanField(db_column='IsSpecial')
    prvd = models.IntegerField(db_column='rf_PRVDID')
    ss = models.CharField(db_column='SS', max_length=14)
    department = models.ForeignKey('OmsDepartment', db_column='rf_DepartmentID', **FK_DEFAULT)
    de_ser = models.DateTimeField(db_column='DE_SER')
    phone = models.CharField(db_column='Phone', max_length=25)

    class Meta:
        managed = False
        db_table = 'hlt_LPUDoctor'



from .base_model import *


class OmsKlTipOms(BaseModel):
    """
    Классификатор типов документов, подтверждающих факт страхования по ОМС (F008)
    """
    id = models.AutoField(db_column='kl_TipOMSID', primary_key=True)  
    date_b = models.DateTimeField(db_column='Date_B')  
    date_e = models.DateTimeField(db_column='Date_E')  
    doc_name = models.CharField(db_column='DOCNAME', max_length=254)  
    id_doc = models.IntegerField(db_column='IDDOC')  

    class Meta:
        managed = False
        db_table = 'oms_kl_TipOMS'



from .base_model import *


class Gender(models.IntegerChoices):
    FEMALE = 0,
    MALE = 1


class HltMkab(BaseModel):
    """
    Медицинская карта амбулаторного больного
    """
    id = models.AutoField(db_column='MKABID', primary_key=True)
    uuid = models.CharField(db_column='UGUID', max_length=36, unique=True, default=uuid.uuid4)
    family = models.CharField(db_column='FAMILY', max_length=40)
    name = models.CharField(db_column='NAME', max_length=40)
    ot = models.CharField(db_column='OT', max_length=40)
    ss = models.CharField(db_column='SS', max_length=14)
    d_type = models.CharField('Признак Особый случай', db_column='D_TYPE', max_length=3)
    num = models.CharField(db_column='NUM', max_length=40)
    w = models.IntegerField(db_column='W', choices=Gender.choices)
    date_bd = models.DateTimeField(db_column='DATE_BD')
    address = models.CharField(db_column='ADRES', max_length=200)
    inv_id = models.IntegerField(db_column='rf_INVID')
    smo = models.ForeignKey('OmsSmo', db_column='rf_SMOID', **FK_DEFAULT)
    other_smo = models.ForeignKey('OmsSmo', db_column='rf_OtherSMOID', **FK_DEFAULT)
    phone_work = models.CharField(db_column='PhoneWork', max_length=20)
    phone_home = models.CharField(db_column='PhoneHome', max_length=20)
    work = models.CharField(db_column='Work', max_length=200)
    profession = models.CharField(db_column='Profession', max_length=50)
    post = models.CharField(db_column='Post', max_length=50)
    dependent = models.BooleanField(db_column='Dependent')
    lpu = models.ForeignKey('OmsLpu', models.DO_NOTHING, db_column='rf_LPUID')
    # rf_group_of_blood = models.ForeignKey('HltGroupOfBloodRh', models.DO_NOTHING, db_column='rf_GroupOfBloodID')
    kindcod = models.BooleanField(db_column='KindCod')
    rh = models.BooleanField(db_column='RH')
    cod_person = models.CharField(db_column='COD_Person', max_length=20)
    military_cod = models.CharField(db_column='MilitaryCOD', max_length=3)
    uchastok = models.ForeignKey('HltUchastok', models.DO_NOTHING, db_column='rf_UchastokID')
    citizen_id = models.IntegerField(db_column='rf_CitizenID')
    type_doc = models.ForeignKey('OmsTypedoc', models.DO_NOTHING, db_column='rf_TYPEDOCID')
    s_doc = models.CharField(db_column='S_DOC', max_length=10)
    n_doc = models.CharField(db_column='N_DOC', max_length=15)
    tip_oms = models.ForeignKey('OmsKlTipOms', db_column='rf_kl_TipOMSID', **FK_DEFAULT)
    s_pol = models.CharField(db_column='S_POL', max_length=50)
    n_pol = models.CharField(db_column='N_POL', max_length=50)
    is_worker = models.BooleanField(db_column='IsWorker')
    mkab_location_id = models.IntegerField(db_column='rf_MKABLocationID')
    spec_event_cert_id = models.IntegerField(db_column='rf_SpecEventCertID')
    address_fact = models.CharField(db_column='AdresFact', max_length=200)
    date_pol_begin = models.DateTimeField(db_column='DatePolBegin')
    date_pol_end = models.DateTimeField(db_column='DatePolEnd')
    enterprise_id = models.IntegerField(db_column='rf_EnterpriseID')
    black_label = models.IntegerField(db_column='BlackLabel')
    okato = models.ForeignKey('OmsOkato', models.DO_NOTHING, db_column='rf_OKATOID')
    is_closed = models.IntegerField(db_column='isClosed')
    reason_close_mkab_id = models.IntegerField(db_column='rf_ReasonCloseMKABID')
    date_close = models.DateTimeField(db_column='DateClose')
    privilege_category_id = models.IntegerField(db_column='rf_kl_PrivilegeCategoryID')
    oms_okved = models.ForeignKey('OmsOkved', models.DO_NOTHING, db_column='rf_omsOKVEDID')
    soc_status = models.ForeignKey('OmsKlSocStatus', db_column='rf_kl_SocStatusID', **FK_DEFAULT)
    sex_id = models.IntegerField(db_column='rf_kl_SexID')
    health_group_id = models.IntegerField(db_column='rf_kl_HealthGroupID')
    address_live = models.ForeignKey('KlaAddress', db_column='rf_AddressLiveID', **FK_DEFAULT)
    address_reg = models.ForeignKey('KlaAddress', db_column='rf_AddressRegID', **FK_DEFAULT)
    address_work = models.ForeignKey('KlaAddress', db_column='rf_AddressWorkID', **FK_DEFAULT)
    confirm_agree = models.BooleanField(db_column='ConfirmAgree')
    confirm_date = models.DateTimeField(db_column='ConfirmDate')
    confirm_user_fio = models.CharField(db_column='ConfirmUserFIO', max_length=50)
    contact_confirm = models.BooleanField(db_column='contactConfirm')
    contact_email = models.CharField(db_column='contactEmail', max_length=100)
    contact_mphone = models.CharField(db_column='contactMPhone', max_length=25)
    create_username = models.CharField(db_column='CreateUserName', max_length=255)
    edit_username = models.CharField(db_column='EditUserName', max_length=255)
    confirm_user = models.ForeignKey('XUser', db_column='rf_ConfirmUserID', **FK_DEFAULT)
    create_user = models.ForeignKey('XUser', db_column='rf_CreateUserID', **FK_DEFAULT)
    edit_user = models.ForeignKey('XUser', db_column='rf_EditUserID', **FK_DEFAULT)
    hash0 = models.CharField(db_column='Hash0', max_length=65)
    hash1 = models.CharField(db_column='Hash1', max_length=65)
    hash2 = models.CharField(db_column='Hash2', max_length=65)
    hash3 = models.CharField(db_column='Hash3', max_length=65)
    hash4 = models.CharField(db_column='Hash4', max_length=65)
    is_encrypted = models.BooleanField(db_column='isEncrypted')
    main_contact = models.IntegerField(db_column='mainContact')
    message_flag = models.IntegerField(db_column='MessageFLAG')
    ridn = models.CharField(db_column='RIDN', max_length=10)
    mkab_info = models.TextField(db_column='MKABInfo')
    birth_place = models.CharField(db_column='Birthplace', max_length=200)
    date_doc = models.DateTimeField(db_column='DateDoc')
    is_ls_home = models.BooleanField(db_column='isLSHome')
    main_mkab = models.ForeignKey('self', models.DO_NOTHING, db_column='MainMKABGuid', to_field='uuid')
    date_mkab = models.DateTimeField(db_column='DateMKAB')
    doc_issued_by = models.CharField(db_column='DocIssuedBy', max_length=255)
    education_type_id = models.IntegerField(db_column='rf_kl_EducationTypeID')
    material_status_id = models.IntegerField(db_column='rf_kl_MaterialStatusID')
    is_auto = models.BooleanField(db_column='isAuto')
    black_label_comment = models.CharField(db_column='BlackLabelComment', max_length=255)
    is_exist_ipra = models.BooleanField(db_column='isExistIPRA')
    oksm_id = models.IntegerField(db_column='rf_OKSMID')
    identification_date = models.DateTimeField(db_column='IdentificationDate')
    identification_status_id = models.IntegerField(db_column='rf_IdentificationStatusID')
    is_no_email = models.BooleanField(db_column='IsNoEmail')
    is_no_phone = models.BooleanField(db_column='IsNoPhone')
    med_intervention = models.SmallIntegerField(db_column='MedIntervention')
    rhesus = models.SmallIntegerField(db_column='Rhesus')
    qualification = models.CharField(db_column='Qualification', max_length=255)
    group = models.CharField(db_column='Group', max_length=255)
    military_duty_id = models.IntegerField(db_column='rf_MilitaryDutyID')
    inn = models.CharField(db_column='INN', max_length=12)
    milk_food_type_id = models.IntegerField(db_column='rf_atc_MilkFoodTypeID')
    milk_food_payment_id = models.IntegerField(db_column='rf_atc_MilkFoodPaymentID')
    food_payment_date = models.DateTimeField(db_column='FoodPaymentDate')

    flags = models.IntegerField(db_column='FLAGS')

    class Meta:
        managed = False
        db_table = 'hlt_MKAB'



from .base_model import *


class HltCallDoctorStatus(BaseModel):
    id = models.AutoField(db_column='CallDoctorStatusID', primary_key=True)
    uuid = models.CharField(db_column='Guid', max_length=36)
    code = models.CharField(db_column='CODE', max_length=50)
    name = models.CharField(db_column='NAME', max_length=50)

    class Meta:
        managed = False
        db_table = 'hlt_CallDoctorStatus'



from .base_model import *


class HltReasonCare(BaseModel):
    """
    Причина выдачи док-та о врем. нетрудоспособности
    """
    id = models.AutoField(db_column='ReasonCareID', primary_key=True)  
    cod = models.CharField(db_column='COD', max_length=6)  
    name = models.CharField(db_column='NAME', max_length=50)  
    date_begin = models.DateTimeField(db_column='DateBegin')  
    date_end = models.DateTimeField(db_column='DateEnd')  

    flags = models.IntegerField(db_column='Flags')

    class Meta:
        managed = False
        db_table = 'hlt_ReasonCare'



from .base_model import *


class AtfFileAttachment(BaseModel):
    id = models.AutoField(db_column='FileAttachmentID', primary_key=True)
    uuid = models.CharField(db_column='Guid', max_length=36, unique=True, default=uuid.uuid4)

    num = models.IntegerField(db_column='Num', default=0)
    description = models.TextField(db_column='Description', default='')
    path = models.CharField(db_column='Path', max_length=500)
    date_create = models.DateTimeField(db_column='DateCreate', default=timezone.now)
    create_username = models.CharField(db_column='CreateUserName', max_length=255, default='')
    create_user = models.ForeignKey('XUser', db_column='rf_CreateUserID', default=0, **FK_DEFAULT)
    file_info = models.ForeignKey('AtfFileInfo', models.DO_NOTHING, related_name='attachments',
                                  db_column='rf_FileInfoID')

    flags = models.IntegerField(db_column='Flags', default=0)

    class Meta:
        managed = False
        db_table = 'atf_FileAttachment'



from .base_model import *


class HltMedRecord(BaseModel):
    id = models.AutoField(db_column='MedRecordID', primary_key=True)
    uuid = models.CharField(db_column='Guid', max_length=36, unique=True, default=uuid.uuid4)
    confidentiality_code = models.CharField(db_column='ConfidentialityCode', max_length=50)
    crc = models.TextField(db_column='CRC')
    data = models.TextField(db_column='Data')
    date = models.DateTimeField(db_column='Date')
    blank_template = models.ForeignKey('HltBlankTemplate', db_column='rf_BlankTemplateID', **FK_DEFAULT)
    lpu_doctor = models.ForeignKey('HltLpuDoctor', db_column='rf_LPUDoctorID', **FK_DEFAULT)
    visit_history = models.ForeignKey('HltVisitHistory', models.DO_NOTHING, db_column='rf_VisitHistoryID',
                                      related_name='med_records')
    sign = models.TextField(db_column='Sign')
    event_data_time = models.DateTimeField(db_column='EventDataTime')
    person = models.ForeignKey('HltMkab', models.DO_NOTHING, db_column='PersonGUID', to_field='uuid',
                               related_name='med_records')
    doc = models.CharField(db_column='rf_DOCGUID', max_length=36)
    doc_type_def = models.CharField(db_column='rf_DocTypeDefGUID', max_length=36)
    view_data = models.TextField(db_column='ViewData')
    create_username = models.CharField(db_column='CreateUserName', max_length=255)
    edit_username = models.CharField(db_column='EditUserName', max_length=255)
    create_user = models.ForeignKey('XUser', db_column='rf_CreateUserID', **FK_DEFAULT)
    edit_user = models.ForeignKey('XUser', db_column='rf_EditUserID', **FK_DEFAULT)
    desc = models.CharField(db_column='DescGuid', max_length=36)
    create_date = models.DateTimeField(db_column='CreateDate')
    description = models.TextField(db_column='Description')
    doc_prvd = models.CharField(db_column='rf_DocPrvdGuid', max_length=36)
    mkab = models.ForeignKey('HltMkab', db_column='rf_MKABGuid', to_field='uuid', **FK_DEFAULT)
    is_upload = models.BooleanField(db_column='isUpload')
    is_del = models.BooleanField(db_column='IsDel')

    flags = models.IntegerField(db_column='Flags')

    class Meta:
        managed = False
        db_table = 'hlt_MedRecord'



from .base_model import *


class KlaStreet(BaseModel):
    id = models.AutoField(db_column='StreetID', primary_key=True) 
    socr = models.CharField(db_column='SOCR', max_length=10) 
    code = models.CharField(db_column='CODE', max_length=17) 
    uno = models.CharField(db_column='UNO', max_length=4) 
    ocatd = models.CharField(db_column='OCATD', max_length=11) 
    source = models.CharField(db_column='Source', max_length=5)
    alt_code = models.CharField(db_column='AltCode', max_length=50)
    name = models.CharField(db_column='Name', max_length=40)
    gninmb = models.CharField(db_column='GNINMB', max_length=4)
    post_index = models.CharField(db_column='PostIndex', max_length=6)
    kladr = models.ForeignKey('KlaKladr', models.DO_NOTHING, db_column='rf_KlAdrID')
    address_string = models.CharField(db_column='AddressString', max_length=500)

    flags = models.IntegerField(db_column='Flags')

    class Meta:
        managed = False
        db_table = 'kla_Street'



from .base_model import *


class HltDocPrvd(BaseModel):
    id = models.AutoField(db_column='DocPRVDID', primary_key=True)  
    lpu_doctor = models.ForeignKey('HltLpuDoctor', db_column='rf_LPUDoctorID', **FK_DEFAULT)
    d_prik = models.DateTimeField(db_column='D_PRIK')  
    s_st = models.DecimalField(db_column='S_ST', max_digits=5, decimal_places=3)  
    d_end = models.DateTimeField(db_column='D_END')  
    prvs = models.ForeignKey('OmsPrvs', db_column='rf_PRVSID', **FK_DEFAULT)
    healing_room_id = models.IntegerField(db_column='rf_HealingRoomID')
    kat_id = models.IntegerField(db_column='rf_KV_KATID')
    department = models.ForeignKey('OmsDepartment', db_column='rf_DepartmentID', **FK_DEFAULT)
    main_work_place = models.BooleanField(db_column='MainWorkPlace')
    guid = models.CharField(db_column='GUID', max_length=36)  
    in_time = models.IntegerField(db_column='InTime')
    prvd = models.ForeignKey('OmsPrvd', db_column='rf_PRVDID', **FK_DEFAULT)
    name = models.CharField(db_column='Name', max_length=100)  
    rf_equipment_id = models.IntegerField(db_column='rf_EquipmentID')
    rf_resource_type_id = models.IntegerField(db_column='rf_ResourceTypeID')
    shown_in_schedule = models.BooleanField(db_column='ShownInSchedule')
    er_id = models.CharField(db_column='ERID', max_length=8000)
    er_name = models.CharField(db_column='ERName', max_length=8000)
    nom_service_code = models.CharField(db_column='NomServiceCode', max_length=50)
    is_special = models.BooleanField(db_column='isSpecial')
    department_type_id = models.IntegerField(db_column='rf_kl_DepartmentTypeID')
    is_dismissal = models.BooleanField(db_column='isDismissal')
    interval = models.IntegerField(db_column='Interval')  
    is_use_interval = models.BooleanField(db_column='isUseInterval')
    pcod = models.CharField(db_column='PCOD', max_length=20)  
    is_conclusion = models.BooleanField(db_column='isConclusion')
    assignment_doctor_id = models.IntegerField(db_column='rf_AssignmentDoctorID')

    class Meta:
        managed = False
        db_table = 'hlt_DocPRVD'
